@@ -2,17 +2,29 @@
 import string
 
 from stackbench.cloud import find_attachment_point
-from stackbench.cloud.base import BaseCloud
+from stackbench.cloud.base import BaseCloud, BaseVolume
 from stackbench.cloud.factory import make_metadata_prop
 
 
 GCE_DISK_PERSISTENT = "PERSISTENT"
 
 
-def translate_attachment_point(disk):
-    return "/dev/sd{0}".format(string.ascii_lowercase[disk["index"]])
+def translate_attachment_point(index):
+    return "/dev/sd{0}".format(string.ascii_lowercase[index])
 
 
+class GCEVolume(BaseVolume):
+    def __init__(self, vol_info):
+        self._vol_info = vol_info
+
+    @property
+    def _cloud_device(self):
+        return translate_attachment_point(self._vol_info["index"])
+
+    @property
+    def persistent(self):
+        return self._vol_info["type"] == GCE_DISK_PERSISTENT
+
 
 class GCE(BaseCloud):
     metadata_server = "http://metadata/computeMetadata/v1beta1"
@@ -35,6 +47,6 @@ class GCE(BaseCloud):
     def attachments(self):
         url = "/".join([self.metadata_server, "instance", "disks/",]) + "?recursive=true"
         res = self.session.get(url)
-        disks = res.json()
-        return dict((find_attachment_point(translate_attachment_point(disk)), disk) for disk in disks if disk["type"] == GCE_DISK_PERSISTENT)
+        volumes_info = res.json()
+        return [GCEVolume(vol_info) for vol_info in volumes_info]
 
